Module Name:    src
Committed By:   andvar
Date:           Sat Feb 10 09:21:54 UTC 2024

Modified Files:
        src/distrib/i386/ramdisks/common: Makefile.ramdisk
        src/lib/libusbhid: usb_hid_usages
        src/libexec/telnetd: state.c
        src/sbin/raidctl: raidctl.c
        src/sys/arch/acorn32/podulebus: if_ne_pbusreg.h
        src/sys/arch/arm/xscale: pxa2x0reg.h
        src/sys/arch/landisk/conf: GENERIC
        src/sys/dev/fdt: fdt_port.h
        src/sys/dev/gpio: gpioirq.c
        src/sys/dev/ic: cs89x0reg.h
        src/sys/dev/isa: if_ix.c
        src/sys/dev/pci: mlyreg.h
        src/sys/dev/raidframe: rf_psstatus.c
        src/sys/dev/usb: ehci.c if_smsc.c if_smscreg.h if_udavreg.h umcs.h
            umidi.c xhcireg.h
        src/sys/dev/vme: sireg.h
        src/sys/fs/udf: udf_readwrite.c udf_strat_direct.c udf_subr.c
        src/sys/kern: sys_pipe.c

Log Message:
fix various typos in comments and log messages.


To generate a diff of this commit:
cvs rdiff -u -r1.14 -r1.15 src/distrib/i386/ramdisks/common/Makefile.ramdisk
cvs rdiff -u -r1.8 -r1.9 src/lib/libusbhid/usb_hid_usages
cvs rdiff -u -r1.33 -r1.34 src/libexec/telnetd/state.c
cvs rdiff -u -r1.82 -r1.83 src/sbin/raidctl/raidctl.c
cvs rdiff -u -r1.3 -r1.4 src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h
cvs rdiff -u -r1.26 -r1.27 src/sys/arch/arm/xscale/pxa2x0reg.h
cvs rdiff -u -r1.77 -r1.78 src/sys/arch/landisk/conf/GENERIC
cvs rdiff -u -r1.6 -r1.7 src/sys/dev/fdt/fdt_port.h
cvs rdiff -u -r1.3 -r1.4 src/sys/dev/gpio/gpioirq.c
cvs rdiff -u -r1.3 -r1.4 src/sys/dev/ic/cs89x0reg.h
cvs rdiff -u -r1.39 -r1.40 src/sys/dev/isa/if_ix.c
cvs rdiff -u -r1.8 -r1.9 src/sys/dev/pci/mlyreg.h
cvs rdiff -u -r1.38 -r1.39 src/sys/dev/raidframe/rf_psstatus.c
cvs rdiff -u -r1.323 -r1.324 src/sys/dev/usb/ehci.c
cvs rdiff -u -r1.93 -r1.94 src/sys/dev/usb/if_smsc.c
cvs rdiff -u -r1.8 -r1.9 src/sys/dev/usb/if_smscreg.h
cvs rdiff -u -r1.16 -r1.17 src/sys/dev/usb/if_udavreg.h
cvs rdiff -u -r1.5 -r1.6 src/sys/dev/usb/umcs.h
cvs rdiff -u -r1.90 -r1.91 src/sys/dev/usb/umidi.c
cvs rdiff -u -r1.23 -r1.24 src/sys/dev/usb/xhcireg.h
cvs rdiff -u -r1.3 -r1.4 src/sys/dev/vme/sireg.h
cvs rdiff -u -r1.13 -r1.14 src/sys/fs/udf/udf_readwrite.c
cvs rdiff -u -r1.16 -r1.17 src/sys/fs/udf/udf_strat_direct.c
cvs rdiff -u -r1.175 -r1.176 src/sys/fs/udf/udf_subr.c
cvs rdiff -u -r1.166 -r1.167 src/sys/kern/sys_pipe.c

Please note that diffs are not public domain; they are subject to the
copyright notices on the relevant files.

Modified files:

Index: src/distrib/i386/ramdisks/common/Makefile.ramdisk
diff -u src/distrib/i386/ramdisks/common/Makefile.ramdisk:1.14 src/distrib/i386/ramdisks/common/Makefile.ramdisk:1.15
--- src/distrib/i386/ramdisks/common/Makefile.ramdisk:1.14	Thu Aug 22 04:25:38 2019
+++ src/distrib/i386/ramdisks/common/Makefile.ramdisk	Sat Feb 10 09:21:51 2024
@@ -1,4 +1,4 @@
-#	$NetBSD: Makefile.ramdisk,v 1.14 2019/08/22 04:25:38 kamil Exp $
+#	$NetBSD: Makefile.ramdisk,v 1.15 2024/02/10 09:21:51 andvar Exp $
 
 NOSANITIZER=	# defined
 
@@ -32,7 +32,7 @@ IMAGEDEPENDS+= 	${CRUNCHBIN} \
 		${DISTRIBDIR}/common/services
 PARSELISTENV+=	BOOTMODEL=${BOOTMODEL:Q}
 
-# This propogates through to the link of ramdiskbin
+# This propagates through to the link of ramdiskbin
 # The map file is useful when trying to prune the image
 LDFLAGS+=	-Wl,-Map,${CRUNCHBIN}.map,--cref
 CRUNCHENV+=	LDFLAGS=${LDFLAGS:Q}

Index: src/lib/libusbhid/usb_hid_usages
diff -u src/lib/libusbhid/usb_hid_usages:1.8 src/lib/libusbhid/usb_hid_usages:1.9
--- src/lib/libusbhid/usb_hid_usages:1.8	Fri Feb  9 22:08:31 2024
+++ src/lib/libusbhid/usb_hid_usages	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-# $NetBSD: usb_hid_usages,v 1.8 2024/02/09 22:08:31 andvar Exp $
+# $NetBSD: usb_hid_usages,v 1.9 2024/02/10 09:21:52 andvar Exp $
 #
 # USB HID usage table
 # Syntax:
@@ -796,7 +796,7 @@
 	0x19F	AL Control Panel
 	0x1A0	AL Command Line Processor/Run
 	0x1A1	AL Process/Task Manager
-	0x1A2	AL Select Tast/Application
+	0x1A2	AL Select Task/Application
 	0x1A3	AL Next Task/Application
 	0x1A4	AL Previous Task/Application
 	0x1A5	AL Preemptive Halt Task/Application

Index: src/libexec/telnetd/state.c
diff -u src/libexec/telnetd/state.c:1.33 src/libexec/telnetd/state.c:1.34
--- src/libexec/telnetd/state.c:1.33	Fri Sep 22 15:28:36 2023
+++ src/libexec/telnetd/state.c	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: state.c,v 1.33 2023/09/22 15:28:36 shm Exp $	*/
+/*	$NetBSD: state.c,v 1.34 2024/02/10 09:21:52 andvar Exp $	*/
 
 /*
  * Copyright (c) 1989, 1993
@@ -34,7 +34,7 @@
 #if 0
 static char sccsid[] = "@(#)state.c	8.5 (Berkeley) 5/30/95";
 #else
-__RCSID("$NetBSD: state.c,v 1.33 2023/09/22 15:28:36 shm Exp $");
+__RCSID("$NetBSD: state.c,v 1.34 2024/02/10 09:21:52 andvar Exp $");
 #endif
 #endif /* not lint */
 
@@ -593,7 +593,7 @@ willoption(int option)
 			 * respond WONT TM to the DO TM that we send to
 			 * check for kludge linemode.  When the WONT TM
 			 * arrives, linemode will be turned off and a
-			 * change propogated to the pty.  This change
+			 * change propagated to the pty.  This change
 			 * will cause us to process the new pty state
 			 * in localstat(), which will notice that
 			 * linemode is off and send a WILL ECHO

Index: src/sbin/raidctl/raidctl.c
diff -u src/sbin/raidctl/raidctl.c:1.82 src/sbin/raidctl/raidctl.c:1.83
--- src/sbin/raidctl/raidctl.c:1.82	Mon Sep 25 21:59:38 2023
+++ src/sbin/raidctl/raidctl.c	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/*      $NetBSD: raidctl.c,v 1.82 2023/09/25 21:59:38 oster Exp $   */
+/*      $NetBSD: raidctl.c,v 1.83 2024/02/10 09:21:52 andvar Exp $   */
 
 /*-
  * Copyright (c) 1996, 1997, 1998 The NetBSD Foundation, Inc.
@@ -39,7 +39,7 @@
 #include <sys/cdefs.h>
 
 #ifndef lint
-__RCSID("$NetBSD: raidctl.c,v 1.82 2023/09/25 21:59:38 oster Exp $");
+__RCSID("$NetBSD: raidctl.c,v 1.83 2024/02/10 09:21:52 andvar Exp $");
 #endif
 
 
@@ -1301,7 +1301,7 @@ rf_simple_create(int fd, int argc, char 
 			cfg.sectPerSU = 16;
 		}
 	} else if (level == 1) {
-		/* 128 blocks (64K per compnent) - 64K per stripe */
+		/* 128 blocks (64K per component) - 64K per stripe */
 		cfg.sectPerSU = 128;
 	} else if (level == 5) {
 		if (num_components == 3) {

Index: src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h
diff -u src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h:1.3 src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h:1.4
--- src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h:1.3	Mon Apr 28 20:23:10 2008
+++ src/sys/arch/acorn32/podulebus/if_ne_pbusreg.h	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_ne_pbusreg.h,v 1.3 2008/04/28 20:23:10 martin Exp $	*/
+/*	$NetBSD: if_ne_pbusreg.h,v 1.4 2024/02/10 09:21:52 andvar Exp $	*/
 
 /*
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -49,7 +49,7 @@
 #define EM_DSR_POL	(1 << 3) /* Polarity of UTP link */
 #define EM_DSR_JAB	(1 << 4) /* Jabber state */
 #define EM_DSR_LNK	(1 << 5) /* Link state */
-#define EM_DSR_LBK	(1 << 6) /* Lookback mode */
+#define EM_DSR_LBK	(1 << 6) /* Loopback mode */
 #define EM_DSR_UTP	(1 << 7) /* Twisted pair selected */
 
 /* EtherLan 600 definitions */

Index: src/sys/arch/arm/xscale/pxa2x0reg.h
diff -u src/sys/arch/arm/xscale/pxa2x0reg.h:1.26 src/sys/arch/arm/xscale/pxa2x0reg.h:1.27
--- src/sys/arch/arm/xscale/pxa2x0reg.h:1.26	Sun Dec 26 16:08:20 2021
+++ src/sys/arch/arm/xscale/pxa2x0reg.h	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: pxa2x0reg.h,v 1.26 2021/12/26 16:08:20 andvar Exp $ */
+/* $NetBSD: pxa2x0reg.h,v 1.27 2024/02/10 09:21:52 andvar Exp $ */
 
 /*
  * Copyright (c) 2002  Genetec Corporation.  All rights reserved.
@@ -985,7 +985,7 @@ struct pxa2x0_dma_desc {
 #define  USBDC_UDCECR_DE	(1<<1)	/* Double-Buffering Enable */
 #define  USBDC_UDCECR_MPE	(1023<<2) /* Maximum Packet Size */
 #define  USBDC_UDCECR_ED	(1<<12)	/* USB Endpoint Direction */
-#define  USBDC_UDCECR_ET	(3<<13)	/* USB Enpoint Type */
+#define  USBDC_UDCECR_ET	(3<<13)	/* USB Endpoint Type */
 #define  USBDC_UDCECR_EN	(15<<15) /* Endpoint Number */
 #define  USBDC_UDCECR_AISN	(7<<19)	/* Alternate Interface Number */
 #define  USBDC_UDCECR_IN	(7<<22)	/* Interface Number */

Index: src/sys/arch/landisk/conf/GENERIC
diff -u src/sys/arch/landisk/conf/GENERIC:1.77 src/sys/arch/landisk/conf/GENERIC:1.78
--- src/sys/arch/landisk/conf/GENERIC:1.77	Mon Jan 29 18:27:13 2024
+++ src/sys/arch/landisk/conf/GENERIC	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-# $NetBSD: GENERIC,v 1.77 2024/01/29 18:27:13 christos Exp $
+# $NetBSD: GENERIC,v 1.78 2024/02/10 09:21:52 andvar Exp $
 #
 # GENERIC machine description file
 #
@@ -22,7 +22,7 @@ include 	"arch/landisk/conf/std.landisk"
 
 options         INCLUDE_CONFIG_FILE     # embed config file in kernel binary
 
-#ident          "GENERIC-$Revision: 1.77 $"
+#ident          "GENERIC-$Revision: 1.78 $"
 
 maxusers	16		# estimated number of users
 
@@ -280,7 +280,7 @@ wskbd*	at ukbd? console ? mux 1
 udl*	at uhub? port ?		# DisplayLink DL-1x0/1x5
 wsdisplay* at udl?
 
-# USB serial adpater
+# USB serial adapter
 ucycom* at uhidev? reportid ?
 
 # USB Generic HID devices

Index: src/sys/dev/fdt/fdt_port.h
diff -u src/sys/dev/fdt/fdt_port.h:1.6 src/sys/dev/fdt/fdt_port.h:1.7
--- src/sys/dev/fdt/fdt_port.h:1.6	Tue May 24 20:50:19 2022
+++ src/sys/dev/fdt/fdt_port.h	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: fdt_port.h,v 1.6 2022/05/24 20:50:19 andvar Exp $	*/
+/*	$NetBSD: fdt_port.h,v 1.7 2024/02/10 09:21:52 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2018 The NetBSD Foundation, Inc.
@@ -75,14 +75,14 @@ enum endpoint_type {
 
 
 /*
- * register a device's ports and enpoints into the provided fdt_device_ports.
+ * register a device's ports and endpoints into the provided fdt_device_ports.
  * when and endpoint is connected to a remote endpoint, dp_ep_connect
  * is called for the devices associated to both endpoints
  */
 int fdt_ports_register(struct fdt_device_ports *, device_t,
 					int, enum endpoint_type);
 
-/* various methods to retrieve an enpoint descriptor */
+/* various methods to retrieve an endpoint descriptor */
 struct fdt_endpoint *fdt_endpoint_get_from_phandle(int);
 struct fdt_endpoint *fdt_endpoint_get_from_index(struct fdt_device_ports *,
 							int, int);

Index: src/sys/dev/gpio/gpioirq.c
diff -u src/sys/dev/gpio/gpioirq.c:1.3 src/sys/dev/gpio/gpioirq.c:1.4
--- src/sys/dev/gpio/gpioirq.c:1.3	Fri Nov 10 13:17:17 2023
+++ src/sys/dev/gpio/gpioirq.c	Sat Feb 10 09:21:52 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: gpioirq.c,v 1.3 2023/11/10 13:17:17 brad Exp $ */
+/* $NetBSD: gpioirq.c,v 1.4 2024/02/10 09:21:52 andvar Exp $ */
 
 /*
  * Copyright (c) 2016, 2023 Brad Spencer <b...@anduin.eldar.org>
@@ -17,7 +17,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: gpioirq.c,v 1.3 2023/11/10 13:17:17 brad Exp $");
+__KERNEL_RCSID(0, "$NetBSD: gpioirq.c,v 1.4 2024/02/10 09:21:52 andvar Exp $");
 
 /*
  * GPIO driver that uses interrupts and can send that fact to userland.
@@ -163,7 +163,7 @@ gpioirq_attach(device_t parent, device_t
 	sc->sc_gpio = ga->ga_gpio;
 	sc->sc_map.pm_map = sc->_map;
 
-	/* Determine our pin configuation. */
+	/* Determine our pin configuration. */
 	sc->sc_npins = gpio_npins(mask);
 	if (sc->sc_npins == 0) {
 		sc->sc_npins = 1;

Index: src/sys/dev/ic/cs89x0reg.h
diff -u src/sys/dev/ic/cs89x0reg.h:1.3 src/sys/dev/ic/cs89x0reg.h:1.4
--- src/sys/dev/ic/cs89x0reg.h:1.3	Sun Dec 11 12:21:26 2005
+++ src/sys/dev/ic/cs89x0reg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: cs89x0reg.h,v 1.3 2005/12/11 12:21:26 christos Exp $	*/
+/*	$NetBSD: cs89x0reg.h,v 1.4 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*
  * Copyright 1997
@@ -358,7 +358,7 @@
 #define MEM_BASE_MASK		0xFFF0
 
 
-/* Adpater Configuration from EEPROM */
+/* Adapter Configuration from EEPROM */
 
 #define ADPTR_CFG_MEDIA		0x0060
 #define ADPTR_CFG_10BASET	0x0020

Index: src/sys/dev/isa/if_ix.c
diff -u src/sys/dev/isa/if_ix.c:1.39 src/sys/dev/isa/if_ix.c:1.40
--- src/sys/dev/isa/if_ix.c:1.39	Tue Jul 12 02:03:57 2022
+++ src/sys/dev/isa/if_ix.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_ix.c,v 1.39 2022/07/12 02:03:57 thorpej Exp $	*/
+/*	$NetBSD: if_ix.c,v 1.40 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*-
  * Copyright (c) 1998 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_ix.c,v 1.39 2022/07/12 02:03:57 thorpej Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_ix.c,v 1.40 2024/02/10 09:21:53 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -841,7 +841,7 @@ ix_attach(device_t parent, device_t self
 	} else
 		media = IFM_ETHER | IFM_10_5;
 
-	/* Take the card out of lookback */
+	/* Take the card out of loopback */
 	bart_config = bus_space_read_1(iot, ioh, IX_CONFIG);
 	bart_config &= ~IX_BART_LOOPBACK;
 	bart_config |= IX_BART_MCS16_TEST; /* inb doesn't get bit! */

Index: src/sys/dev/pci/mlyreg.h
diff -u src/sys/dev/pci/mlyreg.h:1.8 src/sys/dev/pci/mlyreg.h:1.9
--- src/sys/dev/pci/mlyreg.h:1.8	Sun Oct 24 20:00:11 2021
+++ src/sys/dev/pci/mlyreg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: mlyreg.h,v 1.8 2021/10/24 20:00:11 andvar Exp $	*/
+/*	$NetBSD: mlyreg.h,v 1.9 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2001 The NetBSD Foundation, Inc.
@@ -1242,7 +1242,7 @@ union mly_cmd_packet {
  * PG6: 5.4.4 Doorbell 1
  *
  * Note that the documentation claims that these bits are set when the
- * status queue(s) are empty, wheras the Linux driver and experience
+ * status queue(s) are empty, whereas the Linux driver and experience
  * suggest they are set when there is status available.
  */
 #define	MLY_HM_STSREADY			(1<<0)

Index: src/sys/dev/raidframe/rf_psstatus.c
diff -u src/sys/dev/raidframe/rf_psstatus.c:1.38 src/sys/dev/raidframe/rf_psstatus.c:1.39
--- src/sys/dev/raidframe/rf_psstatus.c:1.38	Fri Jul 23 00:54:45 2021
+++ src/sys/dev/raidframe/rf_psstatus.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: rf_psstatus.c,v 1.38 2021/07/23 00:54:45 oster Exp $	*/
+/*	$NetBSD: rf_psstatus.c,v 1.39 2024/02/10 09:21:53 andvar Exp $	*/
 /*
  * Copyright (c) 1995 Carnegie-Mellon University.
  * All rights reserved.
@@ -37,7 +37,7 @@
  *****************************************************************************/
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: rf_psstatus.c,v 1.38 2021/07/23 00:54:45 oster Exp $");
+__KERNEL_RCSID(0, "$NetBSD: rf_psstatus.c,v 1.39 2024/02/10 09:21:53 andvar Exp $");
 
 #include <dev/raidframe/raidframevar.h>
 
@@ -254,7 +254,7 @@ rf_RemoveFromActiveReconTable(RF_Raid_t 
 	hdr->lock = 0;
 	rf_unlock_mutex2(hdr->mutex);
 
-	/* wakup anyone waiting on the parity stripe ID */
+	/* wakeup anyone waiting on the parity stripe ID */
 	cb = p->procWaitList;
 	p->procWaitList = NULL;
 	while (cb) {

Index: src/sys/dev/usb/ehci.c
diff -u src/sys/dev/usb/ehci.c:1.323 src/sys/dev/usb/ehci.c:1.324
--- src/sys/dev/usb/ehci.c:1.323	Fri Feb  9 22:08:36 2024
+++ src/sys/dev/usb/ehci.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: ehci.c,v 1.323 2024/02/09 22:08:36 andvar Exp $ */
+/*	$NetBSD: ehci.c,v 1.324 2024/02/10 09:21:53 andvar Exp $ */
 
 /*
  * Copyright (c) 2004-2012,2016,2020 The NetBSD Foundation, Inc.
@@ -54,7 +54,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: ehci.c,v 1.323 2024/02/09 22:08:36 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: ehci.c,v 1.324 2024/02/10 09:21:53 andvar Exp $");
 
 #include "ohci.h"
 #include "uhci.h"
@@ -4212,7 +4212,7 @@ ehci_device_intr_abort(struct usbd_xfer 
 
 	/*
 	 * XXX - abort_xfer uses ehci_sync_hc, which syncs via the advance
-	 *       async doorbell. That's dependent on the async list, wheras
+	 *       async doorbell. That's dependent on the async list, whereas
 	 *       intr xfers are periodic, should not use this?
 	 */
 	usbd_xfer_abort(xfer);

Index: src/sys/dev/usb/if_smsc.c
diff -u src/sys/dev/usb/if_smsc.c:1.93 src/sys/dev/usb/if_smsc.c:1.94
--- src/sys/dev/usb/if_smsc.c:1.93	Sat Aug 20 14:08:59 2022
+++ src/sys/dev/usb/if_smsc.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_smsc.c,v 1.93 2022/08/20 14:08:59 riastradh Exp $	*/
+/*	$NetBSD: if_smsc.c,v 1.94 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*	$OpenBSD: if_smsc.c,v 1.4 2012/09/27 12:38:11 jsg Exp $	*/
 /*	$FreeBSD: src/sys/dev/usb/net/if_smsc.c,v 1.1 2012/08/15 04:03:55 gonzo Exp $ */
@@ -46,11 +46,11 @@
  * The chip supports both tx and rx offloading of UDP & TCP checksums, this
  * feature can be dynamically enabled/disabled.
  *
- * RX checksuming is performed across bytes after the IPv4 header to the end of
+ * RX checksumming is performed across bytes after the IPv4 header to the end of
  * the Ethernet frame, this means if the frame is padded with non-zero values
  * the H/W checksum will be incorrect, however the rx code compensates for this.
  *
- * TX checksuming is more complicated, the device requires a special header to
+ * TX checksumming is more complicated, the device requires a special header to
  * be prefixed onto the start of the frame which indicates the start and end
  * positions of the UDP or TCP frame.  This requires the driver to manually
  * go through the packet data and decode the headers prior to sending.
@@ -61,7 +61,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: if_smsc.c,v 1.93 2022/08/20 14:08:59 riastradh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: if_smsc.c,v 1.94 2024/02/10 09:21:53 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_usb.h"

Index: src/sys/dev/usb/if_smscreg.h
diff -u src/sys/dev/usb/if_smscreg.h:1.8 src/sys/dev/usb/if_smscreg.h:1.9
--- src/sys/dev/usb/if_smscreg.h:1.8	Wed Apr  6 22:01:45 2022
+++ src/sys/dev/usb/if_smscreg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_smscreg.h,v 1.8 2022/04/06 22:01:45 mlelstv Exp $	*/
+/*	$NetBSD: if_smscreg.h,v 1.9 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*	$OpenBSD: if_smscreg.h,v 1.2 2012/09/27 12:38:11 jsg Exp $	*/
 /*-
@@ -58,7 +58,7 @@
  *      TX_CTRL_0 <12>     Last segment of frame indicator
  *      TX_CTRL_0 <10:0>   Buffer size (payload size)
  *
- *      TX_CTRL_1 <14>     Perform H/W checksuming on IP packets
+ *      TX_CTRL_1 <14>     Perform H/W checksumming on IP packets
  *      TX_CTRL_1 <13>     Disable automatic ethernet CRC generation
  *      TX_CTRL_1 <12>     Disable ethernet frame padding upto 64 bytes
  *      TX_CTRL_1 <10:0>   Packet byte length

Index: src/sys/dev/usb/if_udavreg.h
diff -u src/sys/dev/usb/if_udavreg.h:1.16 src/sys/dev/usb/if_udavreg.h:1.17
--- src/sys/dev/usb/if_udavreg.h:1.16	Sat Aug 10 02:32:27 2019
+++ src/sys/dev/usb/if_udavreg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: if_udavreg.h,v 1.16 2019/08/10 02:32:27 mrg Exp $	*/
+/*	$NetBSD: if_udavreg.h,v 1.17 2024/02/10 09:21:53 andvar Exp $	*/
 /*	$nabe: if_udavreg.h,v 1.2 2003/08/21 16:26:40 nabe Exp $	*/
 
 /*
@@ -63,8 +63,8 @@
 #define	 UDAV_NCR_WAKEEN	(1<<6) /* Wakeup Event Enable */
 #define	 UDAV_NCR_FCOL		(1<<4) /* Force Collision Mode */
 #define	 UDAV_NCR_FDX		(1<<3) /* Full-Duplex Mode (RO on Int. PHY) */
-#define	 UDAV_NCR_LBK1		(1<<2) /* Lookback Mode */
-#define	 UDAV_NCR_LBK0		(1<<1) /* Lookback Mode */
+#define	 UDAV_NCR_LBK1		(1<<2) /* Loopback Mode */
+#define	 UDAV_NCR_LBK0		(1<<1) /* Loopback Mode */
 #define	 UDAV_NCR_RST		(1<<0) /* Software reset */
 
 #define	UDAV_RCR		0x05 /* RX Control Register */

Index: src/sys/dev/usb/umcs.h
diff -u src/sys/dev/usb/umcs.h:1.5 src/sys/dev/usb/umcs.h:1.6
--- src/sys/dev/usb/umcs.h:1.5	Thu Sep 21 09:31:50 2023
+++ src/sys/dev/usb/umcs.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: umcs.h,v 1.5 2023/09/21 09:31:50 msaitoh Exp $ */
+/* $NetBSD: umcs.h,v 1.6 2024/02/10 09:21:53 andvar Exp $ */
 /* $FreeBSD: head/sys/dev/usb/serial/umcs.h 252123 2013-06-23 20:19:51Z thomas $ */
 
 /*-
@@ -38,7 +38,7 @@
 #define	MCS7840_RDREQ		0x0d
 #define	MCS7840_WRREQ		0x0e
 
-/* Read/Wrtie EEPROM values */
+/* Read/Write EEPROM values */
 #define	MCS7840_EEPROM_RW_WVALUE	0x0900
 
 /*

Index: src/sys/dev/usb/umidi.c
diff -u src/sys/dev/usb/umidi.c:1.90 src/sys/dev/usb/umidi.c:1.91
--- src/sys/dev/usb/umidi.c:1.90	Sun Feb  4 05:43:06 2024
+++ src/sys/dev/usb/umidi.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: umidi.c,v 1.90 2024/02/04 05:43:06 mrg Exp $	*/
+/*	$NetBSD: umidi.c,v 1.91 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*
  * Copyright (c) 2001, 2012, 2014 The NetBSD Foundation, Inc.
@@ -32,7 +32,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: umidi.c,v 1.90 2024/02/04 05:43:06 mrg Exp $");
+__KERNEL_RCSID(0, "$NetBSD: umidi.c,v 1.91 2024/02/10 09:21:53 andvar Exp $");
 
 #ifdef _KERNEL_OPT
 #include "opt_usb.h"
@@ -115,7 +115,7 @@ typedef struct {
 #define UMIDI_PACKET_SIZE 4
 
 /*
- * hierarchie
+ * hierarchy
  *
  * <-- parent	       child -->
  *

Index: src/sys/dev/usb/xhcireg.h
diff -u src/sys/dev/usb/xhcireg.h:1.23 src/sys/dev/usb/xhcireg.h:1.24
--- src/sys/dev/usb/xhcireg.h:1.23	Mon Jun  5 03:44:47 2023
+++ src/sys/dev/usb/xhcireg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: xhcireg.h,v 1.23 2023/06/05 03:44:47 mlelstv Exp $ */
+/* $NetBSD: xhcireg.h,v 1.24 2024/02/10 09:21:53 andvar Exp $ */
 
 /*-
  * Copyright (c) 2010 Hans Petter Selasky. All rights reserved.
@@ -92,7 +92,7 @@
 #define	 XHCI_HCC_PAE(x)	__SHIFTOUT((x), __BIT(8))	/* Parse All Event Data */
 #define	 XHCI_HCC_SPC(x)	__SHIFTOUT((x), __BIT(9))	/* Short packet */
 #define	 XHCI_HCC_SEC(x)	__SHIFTOUT((x), __BIT(10))	/* Stopped EDTLA */
-#define	 XHCI_HCC_CFC(x)	__SHIFTOUT((x), __BIT(11))	/* Configuous Frame ID */
+#define	 XHCI_HCC_CFC(x)	__SHIFTOUT((x), __BIT(11))	/* Contiguous Frame ID */
 #define	 XHCI_HCC_MAXPSASIZE_MASK __BITS(15, 12)	/* max pri. stream array size */
 #define	 XHCI_HCC_MAXPSASIZE(x)	__SHIFTOUT((x), XHCI_HCC_MAXPSASIZE_MASK)
 #define	 XHCI_HCC_XECP_MASK	__BITS(31, 16)		/* extended capabilities pointer */
@@ -258,7 +258,7 @@
 /* 5.4.9.2 */
 #define	 XHCI_PM2_L1S_MASK	__BITS(2, 0)	/* RO - L1 status */
 #define	 XHCI_PM2_L1S_GET(x)	__SHIFTOUT((x), XHCI_PM2_L1S_MASK)
-#define	 XHCI_PM2_RWE		__BIT(3)	/* RW - remote wakup enable */
+#define	 XHCI_PM2_RWE		__BIT(3)	/* RW - remote wakeup enable */
 #define	 XHCI_PM2_BESL_MASK	__BITS(7, 4)	/* RW - Best Effort Service Latency */
 #define	 XHCI_PM2_BESL_GET(x)	__SHIFTOUT((x), XHCI_PM2_BESL_MASK)
 #define	 XHCI_PM2_BESL_SET(x)	__SHIFTIN((x), XHCI_PM2_BESL_MASK)

Index: src/sys/dev/vme/sireg.h
diff -u src/sys/dev/vme/sireg.h:1.3 src/sys/dev/vme/sireg.h:1.4
--- src/sys/dev/vme/sireg.h:1.3	Mon Apr 28 20:24:01 2008
+++ src/sys/dev/vme/sireg.h	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: sireg.h,v 1.3 2008/04/28 20:24:01 martin Exp $	*/
+/*	$NetBSD: sireg.h,v 1.4 2024/02/10 09:21:53 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2000 The NetBSD Foundation, Inc.
@@ -30,7 +30,7 @@
  */
 
 /*
- * Register map for the VME SCSI-3 adpater (si)
+ * Register map for the VME SCSI-3 adapter (si)
  * The first part of this register map is an NCR5380
  * SCSI Bus Interface Controller (SBIC).  The rest is a
  * DMA controller and custom logic.

Index: src/sys/fs/udf/udf_readwrite.c
diff -u src/sys/fs/udf/udf_readwrite.c:1.13 src/sys/fs/udf/udf_readwrite.c:1.14
--- src/sys/fs/udf/udf_readwrite.c:1.13	Sun Dec  5 04:32:36 2021
+++ src/sys/fs/udf/udf_readwrite.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: udf_readwrite.c,v 1.13 2021/12/05 04:32:36 msaitoh Exp $ */
+/* $NetBSD: udf_readwrite.c,v 1.14 2024/02/10 09:21:53 andvar Exp $ */
 
 /*
  * Copyright (c) 2007, 2008 Reinoud Zandijk
@@ -28,7 +28,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__KERNEL_RCSID(0, "$NetBSD: udf_readwrite.c,v 1.13 2021/12/05 04:32:36 msaitoh Exp $");
+__KERNEL_RCSID(0, "$NetBSD: udf_readwrite.c,v 1.14 2024/02/10 09:21:53 andvar Exp $");
 #endif /* not lint */
 
 
@@ -272,7 +272,7 @@ udf_fixup_node_internals(struct udf_moun
  * Descriptors inside `logical space' i.e. inside logically mapped partitions
  * can never be longer than one logical sector.
  *
- * NOTE that these functions *can* be used by the sheduler backends to read
+ * NOTE that these functions *can* be used by the scheduler backends to read
  * node descriptors too.
  *
  * For reading, the size of allocated piece is returned in multiple of sector
@@ -323,7 +323,7 @@ udf_read_phys_sectors(struct udf_mount *
 		/* identify this nestbuf */
 		nestbuf->b_lblkno   = lblkno;
 
-		/* CD shedules on raw blkno */
+		/* CD schedules on raw blkno */
 		nestbuf->b_blkno      = rblkno * blks;
 		nestbuf->b_proc       = NULL;
 		nestbuf->b_rawblkno   = rblkno * blks;
@@ -463,7 +463,7 @@ udf_write_phys_buf(struct udf_mount *ump
 		/* identify this nestbuf */
 		nestbuf->b_lblkno   = lblkno;
 
-		/* CD shedules on raw blkno */
+		/* CD schedules on raw blkno */
 		nestbuf->b_blkno      = rblkno * blks;
 		nestbuf->b_proc       = NULL;
 		nestbuf->b_rawblkno   = rblkno * blks;

Index: src/sys/fs/udf/udf_strat_direct.c
diff -u src/sys/fs/udf/udf_strat_direct.c:1.16 src/sys/fs/udf/udf_strat_direct.c:1.17
--- src/sys/fs/udf/udf_strat_direct.c:1.16	Tue Jun 27 09:58:50 2023
+++ src/sys/fs/udf/udf_strat_direct.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: udf_strat_direct.c,v 1.16 2023/06/27 09:58:50 reinoud Exp $ */
+/* $NetBSD: udf_strat_direct.c,v 1.17 2024/02/10 09:21:53 andvar Exp $ */
 
 /*
  * Copyright (c) 2006, 2008 Reinoud Zandijk
@@ -28,7 +28,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__KERNEL_RCSID(0, "$NetBSD: udf_strat_direct.c,v 1.16 2023/06/27 09:58:50 reinoud Exp $");
+__KERNEL_RCSID(0, "$NetBSD: udf_strat_direct.c,v 1.17 2024/02/10 09:21:53 andvar Exp $");
 #endif /* not lint */
 
 
@@ -267,7 +267,7 @@ udf_queue_buf_direct(struct udf_strat_ar
 			queue = UDF_SHED_WRITING;
 	}
 
-	/* use disc sheduler */
+	/* use disc scheduler */
 	class = ump->discinfo.mmc_class;
 	KASSERT((class == MMC_CLASS_UNKN) || (class == MMC_CLASS_DISC) ||
 		(ump->discinfo.mmc_cur & MMC_CAP_HW_DEFECTFREE) ||
@@ -381,7 +381,7 @@ udf_queue_buf_direct(struct udf_strat_ar
 		nestbuf->b_lblkno   = sector;
 		assert(nestbuf->b_vp == buf->b_vp);
 
-		/* CD shedules on raw blkno */
+		/* CD schedules on raw blkno */
 		nestbuf->b_blkno      = rblk;
 		nestbuf->b_proc       = NULL;
 		nestbuf->b_rawblkno   = rblk;

Index: src/sys/kern/sys_pipe.c
diff -u src/sys/kern/sys_pipe.c:1.166 src/sys/kern/sys_pipe.c:1.167
--- src/sys/kern/sys_pipe.c:1.166	Thu Nov  2 10:31:55 2023
+++ src/sys/kern/sys_pipe.c	Sat Feb 10 09:21:54 2024
@@ -1,4 +1,4 @@
-/*	$NetBSD: sys_pipe.c,v 1.166 2023/11/02 10:31:55 martin Exp $	*/
+/*	$NetBSD: sys_pipe.c,v 1.167 2024/02/10 09:21:54 andvar Exp $	*/
 
 /*-
  * Copyright (c) 2003, 2007, 2008, 2009, 2023 The NetBSD Foundation, Inc.
@@ -55,7 +55,7 @@
  */
 
 #include <sys/cdefs.h>
-__KERNEL_RCSID(0, "$NetBSD: sys_pipe.c,v 1.166 2023/11/02 10:31:55 martin Exp $");
+__KERNEL_RCSID(0, "$NetBSD: sys_pipe.c,v 1.167 2024/02/10 09:21:54 andvar Exp $");
 
 #include <sys/param.h>
 #include <sys/systm.h>
@@ -364,7 +364,7 @@ pipeunlock(struct pipe *pipe)
 }
 
 /*
- * Select/poll wakup. This also sends SIGIO to peer connected to
+ * Select/poll wakeup. This also sends SIGIO to peer connected to
  * 'sigpipe' side of pipe.
  */
 static void

Reply via email to
Index: src/sys/fs/udf/udf_subr.c
diff -u src/sys/fs/udf/udf_subr.c:1.175 src/sys/fs/udf/udf_subr.c:1.176
--- src/sys/fs/udf/udf_subr.c:1.175	Sun Feb  4 20:50:30 2024
+++ src/sys/fs/udf/udf_subr.c	Sat Feb 10 09:21:53 2024
@@ -1,4 +1,4 @@
-/* $NetBSD: udf_subr.c,v 1.175 2024/02/04 20:50:30 andvar Exp $ */
+/* $NetBSD: udf_subr.c,v 1.176 2024/02/10 09:21:53 andvar Exp $ */
 
 /*
  * Copyright (c) 2006, 2008 Reinoud Zandijk
@@ -29,7 +29,7 @@
 
 #include <sys/cdefs.h>
 #ifndef lint
-__KERNEL_RCSID(0, "$NetBSD: udf_subr.c,v 1.175 2024/02/04 20:50:30 andvar Exp $");
+__KERNEL_RCSID(0, "$NetBSD: udf_subr.c,v 1.176 2024/02/10 09:21:53 andvar Exp $");
 #endif /* not lint */
 
 
@@ -2087,7 +2087,7 @@ udf_process_vds(struct udf_mount *ump) {
 	}
 
 	/*
 	 * Determine sheduler error behaviour. For virtual partitions, update
 	 * the trackinfo; for sparable partitions replace a whole block on the
 	 * sparable table. Always requeue.
 	 */
@@ -2098,7 +2098,7 @@ udf_process_vds(struct udf_mount *ump) {
 		ump->lvreadwrite = UDF_REMAP_BLOCK;
 
 	/*
 	 * Select our sheduler
 	 */
 	ump->strategy = &udf_strat_rmw;
 	if (n_virt || (ump->discinfo.mmc_cur & MMC_CAP_PSEUDOOVERWRITE))
@@ -2110,7 +2110,7 @@ udf_process_vds(struct udf_mount *ump) {
 		ump->strategy = &udf_strat_rmw;
 
 #if 0
-	/* read-only access won't benefit from the other shedulers */
+	/* read-only access won't benefit from the other schedulers */
 	if (ump->vfs_mountp->mnt_flag & MNT_RDONLY)
 		ump->strategy = &udf_strat_direct;
 #endif
@@ -2130,7 +2130,7 @@ udf_process_vds(struct udf_mount *ump) {
 	snprintb(bits, sizeof(bits), UDFONERROR_BITS, ump->lvreadwrite);
 	DPRINTF(VOLUMES, ("\tactions on logvol errors %s\n", bits));
 
-	DPRINTF(VOLUMES, ("\tselected sheduler `%s`\n",
+	DPRINTF(VOLUMES, ("\tselected scheduler `%s`\n",
 		(ump->strategy == &udf_strat_direct) ? "Direct" :
 		(ump->strategy == &udf_strat_sequential) ? "Sequential" :
 		(ump->strategy == &udf_strat_rmw) ? "RMW" : "UNKNOWN!"));
@@ -6705,7 +6705,7 @@ udf_read_filebuf(struct udf_node *udf_no
 	}
 #endif
 
 	/* request read-in of data from disc sheduler */
 	buf->b_resid = buf->b_bcount;
 	for (sector = 0; sector < sectors; sector++) {
 		buf_offset = sector * sector_size;
@@ -6751,7 +6751,7 @@ udf_read_filebuf(struct udf_node *udf_no
 			nestbuf->b_lblkno   = lblkno;
 			assert(nestbuf->b_vp == udf_node->vnode);
 
-			/* CD shedules on raw blkno */
+			/* CD schedules on raw blkno */
 			nestbuf->b_blkno      = rblk;
 			nestbuf->b_proc       = NULL;
 			nestbuf->b_rawblkno   = rblk;
@@ -6825,7 +6825,7 @@ udf_write_filebuf(struct udf_node *udf_n
 	}
 	DPRINTF(WRITE, ("\tnot intern\n"));
 
 	/* request write out of data to disc sheduler */
 	buf->b_resid = buf->b_bcount;
 	for (lb_num = 0; lb_num < num_lb; lb_num++) {
 		buf_offset = lb_num * lb_size;
@@ -6865,7 +6865,7 @@ udf_write_filebuf(struct udf_node *udf_n
 		nestbuf->b_lblkno   = lblkno;
 		KASSERT(nestbuf->b_vp == udf_node->vnode);
 
-		/* CD shedules on raw blkno */
+		/* CD schedules on raw blkno */
 		nestbuf->b_blkno      = rblk;
 		nestbuf->b_proc       = NULL;
 		nestbuf->b_rawblkno   = rblk;
@@ -2087,7 +2087,7 @@ udf_process_vds(struct udf_mount *ump) {
 
 	/*
-	 * Determine sheduler error behaviour. For virtual partitions, update
+	 * Determine scheduler error behaviour. For virtual partitions, update
 	 * the trackinfo; for sparable partitions replace a whole block on the
 	 * sparable table. Always requeue.
@@ -2098,7 +2098,7 @@ udf_process_vds(struct udf_mount *ump) {
 
 	/*
-	 * Select our sheduler
+	 * Select our scheduler
 	 */
 	ump->strategy = &udf_strat_rmw;
@@ -6705,7 +6705,7 @@ udf_read_filebuf(struct udf_node *udf_no
 #endif
 
-	/* request read-in of data from disc sheduler */
+	/* request read-in of data from disc scheduler */
 	buf->b_resid = buf->b_bcount;
 	for (sector = 0; sector < sectors; sector++) {
@@ -6825,7 +6825,7 @@ udf_write_filebuf(struct udf_node *udf_n
 	DPRINTF(WRITE, ("\tnot intern\n"));
 
-	/* request write out of data to disc sheduler */
+	/* request write out of data to disc scheduler */
 	buf->b_resid = buf->b_bcount;
 	for (lb_num = 0; lb_num < num_lb; lb_num++) {
